aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrPathUtils.cpp
diff options
context:
space:
mode:
authorGravatar commit-bot@chromium.org <commit-bot@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2014-05-20 14:53:45 +0000
committerGravatar commit-bot@chromium.org <commit-bot@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2014-05-20 14:53:45 +0000
commit1878651990d7c9da72cf43481432232bbef3550d (patch)
treefc8d4f6c4a594268c7487cad674c765ee0ef5890 /src/gpu/GrPathUtils.cpp
parent941ff78d79a3239d8a4c18be868423e52563bca5 (diff)
Rename SkMatrix::get(Max|Min)Stretch to get(Min|Max)Scale
R=reed@google.com Author: bsalomon@google.com Review URL: https://codereview.chromium.org/295713002 git-svn-id: http://skia.googlecode.com/svn/trunk@14798 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'src/gpu/GrPathUtils.cpp')
-rw-r--r--src/gpu/GrPathUtils.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gpu/GrPathUtils.cpp b/src/gpu/GrPathUtils.cpp
index 5fead5dea2..81921e36c8 100644
--- a/src/gpu/GrPathUtils.cpp
+++ b/src/gpu/GrPathUtils.cpp
@@ -14,8 +14,8 @@ SkScalar GrPathUtils::scaleToleranceToSrc(SkScalar devTol,
const SkMatrix& viewM,
const SkRect& pathBounds) {
// In order to tesselate the path we get a bound on how much the matrix can
- // stretch when mapping to screen coordinates.
- SkScalar stretch = viewM.getMaxStretch();
+ // scale when mapping to screen coordinates.
+ SkScalar stretch = viewM.getMaxScale();
SkScalar srcTol = devTol;
if (stretch < 0) {